"""Main module fo yamlbase"""
import sys
import os

import YamlBase.ybase
from YamlBase.yamlbase import main
import YamlBase.exceptions
import YamlBase.utils
import YamlBase.table_representation
import YamlBase.yaml_worker
